==> dorsia-0.2.5.tgz: package/src/utility.js <==
const moment = require('../node_modules/moment');
var Table = require('cli-table');

const cityList = {
  "ny": "http://ny.eater.com/maps/best-new-york-restaurants-38",
  "austin": "http://austin.eater.com/maps/best-austin-restaurants-38",
  "nashville": "http://nashville.eater.com/maps/best-nashville-restaurants-18",
  "sf": "http://sf.eater.com/maps/best-san-francisco-restaurants-38",
  "sd":"http://sandiego.eater.com/maps/best-san-diego-restaurants-38",
  "houston": "http://houston.eater.com/maps/best-houston-restaurants-38",
  "minneapolis": "http://minneapolis.eater.com/maps/best-minneapolis-st-paul-restaurants-38",
  "vegas": "http://vegas.eater.com/maps/best-las-vegas-restaurants-38",
  "portland": "http://pdx.eater.com/maps/best-portland-restaurants-38",
  "la": "http://la.eater.com/maps/best-los-angeles-restaurants-38",
  "atl": "http://atlanta.eater.com/maps/best-atlanta-restaurants-38",
  "denver": "http://denver.eater.com/maps/best-denver-restaurants-38",
  "nola" : "http://nola.eater.com/maps/best-new-orleans-restaurants-38",
  "chi": "http://chicago.eater.com/maps/best-chicago-restaurants-38",
  "maine": "http://maine.eater.com/maps/best-maine-restaurants-18",
  "boston": "http://boston.eater.com/maps/best-boston-restaurants-38",
  "detroit": "http://detroit.eater.com/maps/best-detroit-restaurants-38",
  "montreal": "http://montreal.eater.com/maps/best-montreal-restaurants-38",
  "charleston": "http://charleston.eater.com/maps/best-charleston-restaurants-38",
  "dc": "http://dc.eater.com/maps/best-dc-restaurants-38",
  "miami": "http://miami.eater.com/maps/best-miami-restaurants-38",
  "dallas": "http://dallas.eater.com/maps/best-dallas-restaurants-38",
  "philly": "http://philly.eater.com/maps/best-philadelphia-restaurants-38",
  "seattle": "http://seattle.eater.com/maps/best-seattle-restaurants-38"
}



module.exports = {

  createRezObjs: (opentableIdArray, city, date, party, time) => {
    let rezArray = [];
    for (var i = 0; i < opentableIdArray.length; i++) {
      let rez = {
        city: city,
        date: date,
        time: time,
        party: party,
        restId: opentableIdArray[i]
      };
      rezArray.push(rez);
    }
    return rezArray;
  },
  noCity: (cityName) => {
    console.log("No city found for '" + cityName + "'");

    var table = new Table({
       head: ['name','url'],
       colWidths: [14,80]
    });

   for (var prop in cityList) {
     if (cityList.hasOwnProperty(prop)) {
       table.push([prop,cityList[prop]])
     }
   }

   console.log(table.toString());
 },

  todaysDate: () => {
    const time = moment().format("YYYY-MM-DD HH:mm");

    return time;
  },

  getDateTimeString: (date, time) => {

    return moment(date + " " + time).format("YYYY-MM-DD HH:mm");

  },

  cityList: cityList,

  getCityUrl: (name) => {
    return cityList[name];
  },

}

==> dorsia-0.3.7.tgz: package/src/utility.js <==
const moment = require('../node_modules/moment');
var Table = require('cli-table');

const cityList = {
  "ny": "http://ny.eater.com/maps/best-new-york-restaurants-38",
  "austin": "http://austin.eater.com/maps/best-austin-restaurants-38",
  "nashville": "http://nashville.eater.com/maps/best-nashville-restaurants-18",
  "sf": "http://sf.eater.com/maps/best-san-francisco-restaurants-38",
  "sd":"http://sandiego.eater.com/maps/best-san-diego-restaurants-38",
  "houston": "http://houston.eater.com/maps/best-houston-restaurants-38",
  "minneapolis": "http://minneapolis.eater.com/maps/best-minneapolis-st-paul-restaurants-38",
  "vegas": "http://vegas.eater.com/maps/best-las-vegas-restaurants-38",
  "portland": "http://pdx.eater.com/maps/best-portland-restaurants-38",
  "la": "http://la.eater.com/maps/best-los-angeles-restaurants-38",
  "atl": "http://atlanta.eater.com/maps/best-atlanta-restaurants-38",
  "denver": "http://denver.eater.com/maps/best-denver-restaurants-38",
  "nola" : "http://nola.eater.com/maps/best-new-orleans-restaurants-38",
  "chi": "http://chicago.eater.com/maps/best-chicago-restaurants-38",
  "maine": "http://maine.eater.com/maps/best-maine-restaurants-18",
  "boston": "http://boston.eater.com/maps/best-boston-restaurants-38",
  "detroit": "http://detroit.eater.com/maps/best-detroit-restaurants-38",
  "montreal": "http://montreal.eater.com/maps/best-montreal-restaurants-38",
  "charleston": "http://charleston.eater.com/maps/best-charleston-restaurants-38",
  "dc": "http://dc.eater.com/maps/best-dc-restaurants-38",
  "miami": "http://miami.eater.com/maps/best-miami-restaurants-38",
  "dallas": "http://dallas.eater.com/maps/best-dallas-restaurants-38",
  "philly": "http://philly.eater.com/maps/best-philadelphia-restaurants-38",
  "seattle": "http://seattle.eater.com/maps/best-seattle-restaurants-38"
}



module.exports = {

  createRezObjs: (opentableIdArray, party, date, time) => {
    let rezArray = [];
    for (var i = 0; i < opentableIdArray.length; i++) {
      let rez = {
        date: date,
        time: time,
        party: party,
        restId: opentableIdArray[i]
      };
      rezArray.push(rez);
    }
    return rezArray;
  },
  noCity: (cityName) => {
    console.log("No city found for '" + cityName + "'");

    var table = new Table({
       head: ['name','url'],
       colWidths: [14,80]
    });

   for (var prop in cityList) {
     if (cityList.hasOwnProperty(prop)) {
       table.push([prop,cityList[prop]])
     }
   }

   console.log(table.toString());
 },

  todaysDate: () => {
    const time = moment().format("YYYY-MM-DD HH:mm");

    return time;
  },

  getDateTimeString: (date, time) => {

    return moment(date + " " + time).format("YYYY-MM-DD HH:mm");

  },

  cityList: cityList,

  getCityUrl: (name) => {
    return cityList[name];
  },

}
